@@ -1,19 +1,5 @@
 # -*- coding: utf-8 -*-
 
-#  Copyright 2010 Adam Zapletal
-#
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
-
 import os
 import re
 import codecs
@@ -21,13 +7,14 @@ import inspect
 import jinja2
 import shutil
 import tempfile
-import utils
-import ConfigParser
 
 from subprocess import Popen
+from six import string_types
+from six.moves import configparser
 
-import macro as macro_module
-from parser import Parser
+from landslide import utils
+from landslide import macro as macro_module
+from landslide.parser import Parser
 
 
 BASE_DIR = os.path.dirname(__file__)
@@ -86,6 +73,7 @@ class Generator(object):
         self.verbose = kwargs.get('verbose', False)
         self.linenos = self.linenos_check(kwargs.get('linenos'))
         self.watch = kwargs.get('watch', False)
+        self.math_output = kwargs.get('math_output', False)
         self.num_slides = 0
         self.__toc = []
 
@@ -111,6 +99,7 @@ class Generator(object):
                 self.DEFAULT_DESTINATION)
             self.embed = config.get('embed', False)
             self.relative = config.get('relative', False)
+            self.copy_theme = config.get('copy_theme', False)
             self.extensions = config.get('extensions', '')
             self.theme = config.get('theme', 'default')
             self.add_user_css(config.get('css', []))
@@ -145,30 +134,30 @@ class Generator(object):
 
     def add_user_css(self, css_list):
         """ Adds supplementary user css files to the presentation. The
-            ``css_list`` arg can be either a ``list`` or a ``basestring``
-            instance.
+            ``css_list`` arg can be either a ``list`` or a string.
         """
-        if isinstance(css_list, basestring):
+        if isinstance(css_list, string_types):
             css_list = [css_list]
+
         for css_path in css_list:
-            if css_path and not css_path in self.user_css:
+            if css_path and css_path not in self.user_css:
                 if not os.path.exists(css_path):
                     raise IOError('%s user css file not found' % (css_path,))
-                self.user_css.append({
-                    'path_url': utils.get_path_url(css_path, self.relative),
-                    'contents': codecs.open(css_path,
-                                            encoding=self.encoding).read(),
-                })
+                with codecs.open(css_path, encoding=self.encoding) as css_file:
+                    self.user_css.append({
+                        'path_url': utils.get_path_url(css_path,
+                                                       self.relative),
+                        'contents': css_file.read(),
+                    })
 
     def add_user_js(self, js_list):
         """ Adds supplementary user javascript files to the presentation. The
-            ``js_list`` arg can be either a ``list`` or a ``basestring``
-            instance.
+            ``js_list`` arg can be either a ``list`` or a string.
         """
-        if isinstance(js_list, basestring):
+        if isinstance(js_list, string_types):
             js_list = [js_list]
         for js_path in js_list:
-            if js_path and not js_path in self.user_js:
+            if js_path and js_path not in self.user_js:
                 if js_path.startswith("http:"):
                     self.user_js.append({
                         'path_url': js_path,
@@ -177,11 +166,13 @@ class Generator(object):
                 elif not os.path.exists(js_path):
                     raise IOError('%s user js file not found' % (js_path,))
                 else:
-                    self.user_js.append({
-                        'path_url': utils.get_path_url(js_path, self.relative),
-                        'contents': codecs.open(js_path,
-                            encoding=self.encoding).read(),
-                    })
+                    with codecs.open(js_path,
+                                     encoding=self.encoding) as js_file:
+                        self.user_js.append({
+                            'path_url': utils.get_path_url(js_path,
+                                                           self.relative),
+                            'contents': js_file.read(),
+                        })
 
     def add_toc_entry(self, title, level, slide_number):
         """ Adds a new entry to current presentation Table of Contents.
@@ -212,12 +203,12 @@ class Generator(object):
                 raise IOError(u"Direct output mode is not available for PDF "
                                "export")
             else:
-                print self.render().encode(self.encoding)
+                print(self.render().encode(self.encoding))
         else:
             self.write_and_log()
 
             if self.watch:
-                from watcher import watch
+                from landslide.watcher import watch
 
                 self.log(u"Watching %s\n" % self.watch_dir)
 
@@ -265,8 +256,8 @@ class Generator(object):
             self.log(u"Adding   %s (%s)" % (source, parser.format))
 
             try:
-                file = codecs.open(source, encoding=self.encoding)
-                file_contents = file.read()
+                with codecs.open(source, encoding=self.encoding) as file:
+                    file_contents = file.read()
             except UnicodeDecodeError:
                 self.log(u"Unable to decode source %s: skipping" % source,
                          'warning')
@@ -296,7 +287,7 @@ class Generator(object):
             if not os.path.exists(target_theme_dir):
                 try:
                     shutil.copytree(self.theme_dir, target_theme_dir)
-                except Exception, e:
+                except Exception as e:
                     self.log(u"Skipped copy of theme folder: %s" % e)
                     pass
             self.theme_dir = target_theme_dir
@@ -310,6 +301,7 @@ class Generator(object):
         css = {}
 
         print_css = os.path.join(self.theme_dir, 'css', 'print.css')
+
         if not os.path.exists(print_css):
             # Fall back to default theme
             print_css = os.path.join(THEMES_DIR, 'default', 'css', 'print.css')
@@ -317,18 +309,20 @@ class Generator(object):
             if not os.path.exists(print_css):
                 raise IOError(u"Cannot find css/print.css in default theme")
 
-        css['print'] = {
-            'path_url': utils.get_path_url(print_css, self.relative),
-            'contents': codecs.open(print_css, encoding=self.encoding).read(),
-        }
+        with codecs.open(print_css, encoding=self.encoding) as css_file:
+            css['print'] = {
+                'path_url': utils.get_path_url(print_css, self.relative),
+                'contents': css_file.read(),
+            }
 
         screen_css = os.path.join(self.theme_dir, 'css', 'screen.css')
+
         if (os.path.exists(screen_css)):
-            css['screen'] = {
-                'path_url': utils.get_path_url(screen_css, self.relative),
-                'contents': codecs.open(screen_css,
-                                        encoding=self.encoding).read(),
-            }
+            with codecs.open(screen_css, encoding=self.encoding) as css_file:
+                css['screen'] = {
+                    'path_url': utils.get_path_url(screen_css, self.relative),
+                    'contents': css_file.read(),
+                }
         else:
             self.log(u"No screen stylesheet provided in current theme",
                       'warning')
@@ -346,19 +340,29 @@ class Generator(object):
 
             if not os.path.exists(js_file):
                 raise IOError(u"Cannot find slides.js in default theme")
-
-        return {
-            'path_url': utils.get_path_url(js_file, self.relative),
-            'contents': codecs.open(js_file, encoding=self.encoding).read(),
-        }
+        with codecs.open(js_file, encoding=self.encoding) as js_file_obj:
+            return {
+                'path_url': utils.get_path_url(js_file, self.relative),
+                'contents': js_file_obj.read(),
+            }
 
     def get_slide_vars(self, slide_src, source=None):
         """ Computes a single slide template vars from its html source code.
             Also extracts slide informations for the table of contents.
         """
+        presenter_notes = None
+
+        find = re.search(r'<h\d[^>]*>presenter notes</h\d>', slide_src,
+                         re.DOTALL | re.UNICODE | re.IGNORECASE)
+
+        if find:
+            if self.presenter_notes:
+                presenter_notes = slide_src[find.end():].strip()
+
+            slide_src = slide_src[:find.start()]
+
         find = re.search(r'(<h(\d+?).*?>(.+?)</h\d>)\s?(.+)?', slide_src,
                          re.DOTALL | re.UNICODE)
-        presenter_notes = None
 
         if not find:
             header = level = title = None
@@ -377,14 +381,6 @@ class Generator(object):
         if content:
             content, slide_classes = self.process_macros(content, source)
 
-            find = re.search(r'<h\d[^>]*>presenter notes</h\d>', content,
-                             re.DOTALL | re.UNICODE | re.IGNORECASE)
-
-            if find:
-                if self.presenter_notes:
-                    presenter_notes = content[find.end():].strip()
-                content = content[:find.start()]
-
         source_dict = {}
 
         if source:
@@ -394,7 +390,8 @@ class Generator(object):
         if header or content:
             return {'header': header, 'title': title, 'level': level,
                     'content': content, 'classes': slide_classes,
-                    'source': source_dict, 'presenter_notes': presenter_notes}
+                    'source': source_dict, 'presenter_notes': presenter_notes,
+                    'math_output': self.math_output}
 
     def get_template_vars(self, slides):
         """ Computes template vars from slides html source code.
@@ -419,7 +416,8 @@ class Generator(object):
         return {'head_title': head_title, 'num_slides': str(self.num_slides),
                 'slides': slides, 'toc': self.toc, 'embed': self.embed,
                 'css': self.get_css(), 'js': self.get_js(),
-                'user_css': self.user_css, 'user_js': self.user_js}
+                'user_css': self.user_css, 'user_js': self.user_js,
+                'math_output': self.math_output}
 
     def linenos_check(self, value):
         """ Checks and returns a valid value for the ``linenos`` option.
@@ -440,9 +438,9 @@ class Generator(object):
         """
         self.log(u"Config   %s" % config_source)
         try:
-            raw_config = ConfigParser.RawConfigParser()
+            raw_config = configparser.RawConfigParser()
             raw_config.read(config_source)
-        except Exception, e:
+        except Exception as e:
             raise RuntimeError(u"Invalid configuration file: %s" % e)
         config = {}
         config['source'] = raw_config.get('landslide', 'source')\
@@ -454,10 +452,9 @@ class Generator(object):
             config['destination'] = raw_config.get('landslide', 'destination')
         if raw_config.has_option('landslide', 'linenos'):
             config['linenos'] = raw_config.get('landslide', 'linenos')
-        if raw_config.has_option('landslide', 'embed'):
-            config['embed'] = raw_config.getboolean('landslide', 'embed')
-        if raw_config.has_option('landslide', 'relative'):
-            config['relative'] = raw_config.getboolean('landslide', 'relative')
+        for boolopt in ('embed', 'relative', 'copy_theme'):
+            if raw_config.has_option('landslide', boolopt):
+                config[boolopt] = raw_config.getboolean('landslide', boolopt)
         if raw_config.has_option('landslide', 'extensions'):
             config['extensions'] = ",".join(raw_config.get('landslide', 'extensions')\
                 .replace('\r', '').split('\n'))
@@ -481,7 +478,7 @@ class Generator(object):
                 content, add_classes = macro.process(content, source)
                 if add_classes:
                     classes += add_classes
-            except Exception, e:
+            except Exception as e:
                 self.log(u"%s processing failed in %s: %s"
                          % (macro, source, e))
         return content, classes
@@ -499,16 +496,16 @@ class Generator(object):
     def render(self):
         """ Returns generated html code.
         """
-        template_src = codecs.open(self.template_file, encoding=self.encoding)
-        template = jinja2.Template(template_src.read())
+        with codecs.open(self.template_file, encoding=self.encoding) as template_src:
+            template = jinja2.Template(template_src.read())
         slides = self.fetch_contents(self.source)
         context = self.get_template_vars(slides)
 
         html = template.render(context)
 
         if self.embed:
-            images = re.findall(r'\s+background(?:-image)?:\surl\((.+?)\).+;',
-                            html, re.DOTALL | re.UNICODE)
+            images = re.findall(r'url\(["\']?(.*?\.(?:jpe?g|gif|png|svg)[\'"]?)\)',
+                html, re.DOTALL | re.UNICODE)
 
             for img_url in images:
                 img_url = img_url.replace('"', '').replace("'", '')
@@ -526,22 +523,20 @@ class Generator(object):
                     found = False
                     for css_entry in context['user_css']:
                         directory = os.path.dirname(css_entry['path_url'])
-                        if not directory: 
+                        if not directory:
                             directory = "."
 
                         encoded_url = utils.encode_image_from_url(img_url, directory)
-                            
+
                         if encoded_url:
                             found = True
                             html = html.replace(img_url, encoded_url, 1)
                             self.log("Embedded theme image %s from directory %s" % (img_url, directory))
-                    
+
                     if not found:
-                        #Missing image file, etc...
+                        # Missing image file, etc...
                         self.log(u"Failed to embed theme image %s" % img_url)
 
-
-
         return html
 
     def write(self):
@@ -552,8 +547,9 @@ class Generator(object):
         if self.file_type == 'pdf':
             self.write_pdf(html)
         else:
-            outfile = codecs.open(self.destination_file, 'w', encoding='utf_8')
-            outfile.write(html)
+            with codecs.open(self.destination_file, 'w',
+                             encoding='utf_8') as outfile:
+                outfile.write(html)
 
     def write_pdf(self, html):
         """ Tries to write a PDF export from the command line using PrinceXML
