@@ -1,25 +1,11 @@
 # -*- coding: utf-8 -*-
 
-#  Copyright 2010 Adam Zapletal
-#
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
-
 import os
 import re
-import htmlentitydefs
+from six.moves import html_entities
 import pygments
 import sys
-import utils
+from landslide import utils
 
 from pygments.lexers import get_lexer_by_name
 from pygments.formatters import HtmlFormatter
@@ -58,7 +44,7 @@ class CodeHighlightingMacro(Macro):
     def descape(self, string, defs=None):
         """Decodes html entities from a given string"""
         if defs is None:
-            defs = htmlentitydefs.entitydefs
+            defs = html_entities.entitydefs
         f = lambda m: defs[m.group(1)] if len(m.groups()) > 0 else m.group(0)
         return self.html_entity_re.sub(f, string)
 
@@ -129,14 +115,17 @@ class FixImagePathsMacro(Macro):
 
         if self.embed:
             return content, classes
+
         base_path = utils.get_path_url(source, self.options.get('relative'))
         base_url = os.path.split(base_path)[0]
 
-        images = re.findall(r'<img.*?src="(?!http://)(.*?)".*/?>', content,
-            re.DOTALL | re.UNICODE)
+        regex = r'<img.*?src="(?!https?://|file://)(.*?)".*?/?>'
 
-        for image in images:
-            full_path = os.path.join(base_url, image)
+        images = re.findall(regex, content, re.DOTALL | re.UNICODE)
+
+        for image in list(set(images)):
+            full_path = '"' + os.path.join(base_url, image) + '"'
+            image = '"' + image + '"'
 
             content = content.replace(image, full_path)
 
