@@ -1,29 +1,14 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-#  Copyright 2010 Adam Zapletal
-#
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
-
 import sys
 
-try:
-    from landslide import generator
-except ImportError:
-    import generator
-
 from optparse import OptionParser
 
+from landslide import generator
+
+from . import __version__
+
 
 def _parse_options():
     """ Parses ``landslide`` args options.
@@ -34,7 +19,8 @@ def _parse_options():
         description="Generates an HTML5 or PDF "
                     "slideshow from Markdown or other formats",
         epilog="Note: PDF export requires the `prince` program: "
-               "http://princexml.com/")
+               "http://princexml.com/",
+        version="%prog " + __version__)
 
     parser.add_option(
         "-c", "--copy-theme",
@@ -146,6 +132,14 @@ def _parse_options():
         default=False
     )
 
+    parser.add_option(
+        "-m", "--math-output",
+        action="store_true",
+        dest="math_output",
+        help="Enable mathematical output using MathJax",
+        default=False
+    )
+
     (options, args) = parser.parse_args()
 
     if not args:
@@ -178,7 +172,7 @@ def main():
     else:
         try:
             run(input_file, options)
-        except Exception, e:
+        except Exception as e:
             sys.stderr.write("Error: %s\n" % e)
             sys.exit(1)
 
